pub struct FilteredEntityRef<'w, 's> { /* private fields */ }Expand description
Provides read-only access to a single entity and some of its components defined by the contained Access.
To define the access when used as a QueryData,
use a QueryBuilder or QueryParamBuilder.
The FilteredEntityRef must be the entire QueryData, and not nested inside a tuple with other data.
// This gives the `FilteredEntityRef` access to `&A`.
let mut query = QueryBuilder::<FilteredEntityRef>::new(&mut world)
.data::<&A>()
.build();
let filtered_entity: FilteredEntityRef = query.single(&mut world).unwrap();
let component: &A = filtered_entity.get().unwrap();Implementations
Sourceimpl<'w, 's> FilteredEntityRef<'w, 's>
impl<'w, 's> FilteredEntityRef<'w, 's>
Sourcepub fn try_into_all(self) -> Result<EntityRef<'w>, TryFromFilteredError>
pub fn try_into_all(self) -> Result<EntityRef<'w>, TryFromFilteredError>
Consumes self and returns read-only access to the entity and all of
its components, with the world 'w lifetime. Returns an error if the
access does not include read access to all components.
Errors
TryFromFilteredError::MissingReadAllAccess- if the access does not include read access to all components.
Sourcepub fn location(&self) -> EntityLocation
pub fn location(&self) -> EntityLocation
Gets metadata indicating the location where the current entity is stored.
Sourcepub fn archetype(&self) -> &Archetype
pub fn archetype(&self) -> &Archetype
Returns the archetype that the current entity belongs to.
Sourcepub fn contains<T: Component>(&self) -> bool
pub fn contains<T: Component>(&self) -> bool
Returns true if the current entity has a component of type T.
Otherwise, this returns false.
Notes
If you do not know the concrete type of a component, consider using
Self::contains_id or Self::contains_type_id.
Sourcepub fn contains_id(&self, component_id: ComponentId) -> bool
pub fn contains_id(&self, component_id: ComponentId) -> bool
Returns true if the current entity has a component identified by component_id.
Otherwise, this returns false.
Notes
- If you know the concrete type of the component, you should prefer
Self::contains. - If you know the component’s
TypeIdbut not itsComponentId, consider usingSelf::contains_type_id.
Sourcepub fn contains_type_id(&self, type_id: TypeId) -> bool
pub fn contains_type_id(&self, type_id: TypeId) -> bool
Returns true if the current entity has a component with the type identified by type_id.
Otherwise, this returns false.
Notes
- If you know the concrete type of the component, you should prefer
Self::contains. - If you have a
ComponentIdinstead of aTypeId, consider usingSelf::contains_id.
Sourcepub fn get<T: Component>(&self) -> Option<&'w T>
pub fn get<T: Component>(&self) -> Option<&'w T>
Gets access to the component of type T for the current entity.
Returns None if the entity does not have a component of type T.
Sourcepub fn get_ref<T: Component>(&self) -> Option<Ref<'w, T>>
pub fn get_ref<T: Component>(&self) -> Option<Ref<'w, T>>
Gets access to the component of type T for the current entity,
including change detection information as a Ref.
Returns None if the entity does not have a component of type T.
Sourcepub fn get_change_ticks<T: Component>(&self) -> Option<ComponentTicks>
pub fn get_change_ticks<T: Component>(&self) -> Option<ComponentTicks>
Retrieves the change ticks for the given component. This can be useful for implementing change detection in custom runtimes.
Sourcepub fn get_change_ticks_by_id(
&self,
component_id: ComponentId,
) -> Option<ComponentTicks>
pub fn get_change_ticks_by_id( &self, component_id: ComponentId, ) -> Option<ComponentTicks>
Retrieves the change ticks for the given ComponentId. This can be useful for implementing change
detection in custom runtimes.
You should prefer to use the typed API Self::get_change_ticks where possible and only
use this in cases where the actual component types are not known at
compile time.
Sourcepub fn get_by_id(&self, component_id: ComponentId) -> Option<Ptr<'w>>
pub fn get_by_id(&self, component_id: ComponentId) -> Option<Ptr<'w>>
Gets the component of the given ComponentId from the entity.
You should prefer to use the typed API Self::get where possible and only
use this in cases where the actual component types are not known at
compile time.
Unlike FilteredEntityRef::get, this returns a raw pointer to the component,
which is only valid while the FilteredEntityRef is alive.
Sourcepub fn spawned_by(&self) -> MaybeLocation
pub fn spawned_by(&self) -> MaybeLocation
Returns the source code location from which this entity has been spawned.
Sourcepub fn spawn_tick(&self) -> Tick
pub fn spawn_tick(&self) -> Tick
Returns the Tick at which this entity has been spawned.